package com.ztmap.project.zhny.energystoragefdsdycs.service.impl;

import java.util.List;
import com.ztmap.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.energystoragefdsdycs.mapper.TEnergyStorageFdsdycsMapper;
import com.ztmap.project.zhny.energystoragefdsdycs.domain.TEnergyStorageFdsdycs;
import com.ztmap.project.zhny.energystoragefdsdycs.service.ITEnergyStorageFdsdycsService;
import com.ztmap.common.utils.text.Convert;

/**
 * 放电深度与次数Service业务层处理
 * 
 * @author ztmap
 * @date 2023-10-09
 */
@Service
public class TEnergyStorageFdsdycsServiceImpl implements ITEnergyStorageFdsdycsService 
{
    @Autowired
    private TEnergyStorageFdsdycsMapper tEnergyStorageFdsdycsMapper;

    /**
     * 查询放电深度与次数
     * 
     * @param id 放电深度与次数ID
     * @return 放电深度与次数
     */
    @Override
    public TEnergyStorageFdsdycs selectTEnergyStorageFdsdycsById(Long id)
    {
        return tEnergyStorageFdsdycsMapper.selectTEnergyStorageFdsdycsById(id);
    }

    /**
     * 查询放电深度与次数列表
     * 
     * @param tEnergyStorageFdsdycs 放电深度与次数
     * @return 放电深度与次数
     */
    @Override
    public List<TEnergyStorageFdsdycs> selectTEnergyStorageFdsdycsList(TEnergyStorageFdsdycs tEnergyStorageFdsdycs)
    {
        return tEnergyStorageFdsdycsMapper.selectTEnergyStorageFdsdycsList(tEnergyStorageFdsdycs);
    }

    /**
     * 新增放电深度与次数
     * 
     * @param tEnergyStorageFdsdycs 放电深度与次数
     * @return 结果
     */
    @Override
    public int insertTEnergyStorageFdsdycs(TEnergyStorageFdsdycs tEnergyStorageFdsdycs)
    {
        tEnergyStorageFdsdycs.setCreateTime(DateUtils.getNowDate());
        return tEnergyStorageFdsdycsMapper.insertTEnergyStorageFdsdycs(tEnergyStorageFdsdycs);
    }

    /**
     * 修改放电深度与次数
     * 
     * @param tEnergyStorageFdsdycs 放电深度与次数
     * @return 结果
     */
    @Override
    public int updateTEnergyStorageFdsdycs(TEnergyStorageFdsdycs tEnergyStorageFdsdycs)
    {
        return tEnergyStorageFdsdycsMapper.updateTEnergyStorageFdsdycs(tEnergyStorageFdsdycs);
    }

    /**
     * 删除放电深度与次数对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTEnergyStorageFdsdycsByIds(String ids)
    {
        return tEnergyStorageFdsdycsMapper.deleteTEnergyStorageFdsdycsByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除放电深度与次数信息
     * 
     * @param id 放电深度与次数ID
     * @return 结果
     */
    @Override
    public int deleteTEnergyStorageFdsdycsById(Long id)
    {
        return tEnergyStorageFdsdycsMapper.deleteTEnergyStorageFdsdycsById(id);
    }
}
